import BigNumber from 'bignumber.js';
import { AddInstructionWithVenueIdParams } from "./api/procedures/addInstruction";
import { AffirmInstructionParams } from "./api/procedures/modifyInstructionAffirmation";
import { Context, CreateVenueParams, Instruction, Venue } from "./internal";
import { ProcedureMethod } from "./types";
/**
 * Handles all Settlement related functionality
 */
export declare class Settlements {
    private context;
    /**
     * @hidden
     */
    constructor(context: Context);
    /**
     * Retrieve a Venue by its ID
     *
     * @param id - identifier number of the Venue
     */
    getVenue(args: {
        id: BigNumber;
    }): Promise<Venue>;
    /**
     * Retrieve an Instruction by its ID
     *
     * @param id - identifier number of the Instruction
     */
    getInstruction(args: {
        id: BigNumber;
    }): Promise<Instruction>;
    /**
     * Create a Venue under the ownership of the signing Identity
     */
    createVenue: ProcedureMethod<CreateVenueParams, Venue>;
    /**
     * Create an Instruction to exchange Assets
     */
    addInstruction: ProcedureMethod<AddInstructionWithVenueIdParams, Instruction[], Instruction>;
    /**
     * Affirm an Instruction (authorize)
     */
    affirmInstruction: ProcedureMethod<AffirmInstructionParams, Instruction>;
}
//# sourceMappingURL=Settlements.d.ts.map