import BigNumber from 'bignumber.js';
import { Asset, Checkpoint, Context, Namespace } from "../../../../internal";
import { CheckpointWithData, NoArgsProcedureMethod, PaginationOptions, ResultSet } from "../../../../types";
import { Schedules } from './Schedules';
/**
 * Handles all Asset Checkpoints related functionality
 */
export declare class Checkpoints extends Namespace<Asset> {
    schedules: Schedules;
    /**
     * @hidden
     */
    constructor(parent: Asset, context: Context);
    /**
     * Create a snapshot of Asset Holders and their respective balances at this moment
     */
    create: NoArgsProcedureMethod<Checkpoint>;
    /**
     * Retrieve a single Checkpoint for this Asset by its ID
     *
     * @throws if there is no Checkpoint with the passed ID
     */
    getOne(args: {
        id: BigNumber;
    }): Promise<Checkpoint>;
    /**
     * Retrieve all Checkpoints created on this Asset, together with their corresponding creation Date and Total Supply
     *
     * @note supports pagination
     */
    get(paginationOpts?: PaginationOptions): Promise<ResultSet<CheckpointWithData>>;
}
//# sourceMappingURL=index.d.ts.map