import BigNumber from 'bignumber.js';
import { Asset, ConfigureDividendDistributionParams, Context, DividendDistribution, Namespace } from "../../../../internal";
import { DistributionWithDetails, ProcedureMethod } from "../../../../types";
/**
 * Handles all Asset Distributions related functionality
 */
export declare class Distributions extends Namespace<Asset> {
    /**
     * Create a Dividend Distribution for a subset of the Asset Holders at a certain (existing or future) Checkpoint
     *
     * @note required role:
     *   - Origin Portfolio Custodian
     */
    configureDividendDistribution: ProcedureMethod<ConfigureDividendDistributionParams, DividendDistribution>;
    /**
     * @hidden
     */
    constructor(parent: Asset, context: Context);
    /**
     * Retrieve a single Dividend Distribution associated to this Asset by its ID
     *
     * @throws if there is no Distribution with the passed ID
     */
    getOne(args: {
        id: BigNumber;
    }): Promise<DistributionWithDetails>;
    /**
     * Retrieve all Dividend Distributions associated to this Asset, along with their details
     */
    get(): Promise<DistributionWithDetails[]>;
}
//# sourceMappingURL=Distributions.d.ts.map