import type { Vec, u32, u64, u8 } from '@polkadot/types';
import type { Balance, BalanceOf, BlockNumber, Moment, Perbill, Permill, RuntimeDbWeight } from '@polkadot/types/interfaces/runtime';
import type { SessionIndex } from '@polkadot/types/interfaces/session';
import type { EraIndex } from '@polkadot/types/interfaces/staking';
import type { RuntimeVersion } from '@polkadot/types/interfaces/state';
import type { WeightToFeeCoefficient } from '@polkadot/types/interfaces/support';
import type { BlockLength, BlockWeights } from '@polkadot/types/interfaces/system';
import type { ApiTypes } from '@polkadot/api/types';
declare module '@polkadot/api/types/consts' {
    interface AugmentedConsts<ApiType> {
        asset: {
            assetNameMaxLength: u32 & AugmentedConst<ApiType>;
            fundingRoundNameMaxLength: u32 & AugmentedConst<ApiType>;
            maxNumberOfTmExtensionForAsset: u32 & AugmentedConst<ApiType>;
        };
        babe: {
            /**
             * The number of **slots** that an epoch takes. We couple sessions to
             * epochs, i.e. we start a new session once the new epoch begins.
             * NOTE: Currently it is not possible to change the epoch duration
             * after the chain has started. Attempting to do so will brick block
             * production.
             **/
            epochDuration: u64 & AugmentedConst<ApiType>;
            /**
             * The expected average block time at which BABE should be creating
             * blocks. Since BABE is probabilistic it is not trivial to figure out
             * what the expected average block time should be based on the slot
             * duration and the security parameter `c` (where `1 - c` represents
             * the probability of a slot being empty).
             **/
            expectedBlockTime: Moment & AugmentedConst<ApiType>;
        };
        balances: {
            /**
             * The minimum amount required to keep an account open.
             **/
            existentialDeposit: Balance & AugmentedConst<ApiType>;
        };
        base: {
            maxLen: u32 & AugmentedConst<ApiType>;
        };
        complianceManager: {
            maxConditionComplexity: u32 & AugmentedConst<ApiType>;
        };
        corporateAction: {
            maxDidWhts: u32 & AugmentedConst<ApiType>;
            maxTargetIds: u32 & AugmentedConst<ApiType>;
        };
        identity: {
            initialPolyx: Balance & AugmentedConst<ApiType>;
        };
        indices: {
            /**
             * The deposit needed for reserving an index.
             **/
            deposit: BalanceOf & AugmentedConst<ApiType>;
        };
        staking: {
            /**
             * Number of eras that staked funds must remain bonded for.
             **/
            bondingDuration: EraIndex & AugmentedConst<ApiType>;
            /**
             * The number of blocks before the end of the era from which election submissions are allowed.
             *
             * Setting this to zero will disable the offchain compute and only on-chain seq-phragmen will
             * be used.
             *
             * This is bounded by being within the last session. Hence, setting it to a value more than the
             * length of a session will be pointless.
             **/
            electionLookahead: BlockNumber & AugmentedConst<ApiType>;
            /**
             * Total year rewards that gets paid during fixed reward schedule.
             **/
            fixedYearlyReward: BalanceOf & AugmentedConst<ApiType>;
            /**
             * Maximum number of balancing iterations to run in the offchain submission.
             *
             * If set to 0, balance_solution will not be executed at all.
             **/
            maxIterations: u32 & AugmentedConst<ApiType>;
            /**
             * The maximum number of nominators rewarded for each validator.
             *
             * For each validator only the `$MaxNominatorRewardedPerValidator` biggest stakers can claim
             * their reward. This used to limit the i/o cost for the nominator payout.
             **/
            maxNominatorRewardedPerValidator: u32 & AugmentedConst<ApiType>;
            /**
             * Maximum number of validators for each permissioned identity.
             *
             * Max number of validators count = `MaxValidatorPerIdentity * Self::validator_count()`.
             **/
            maxValidatorPerIdentity: Permill & AugmentedConst<ApiType>;
            /**
             * Maximum amount of `T::currency::total_issuance()` after that non-inflated rewards get paid.
             **/
            maxVariableInflationTotalIssuance: BalanceOf & AugmentedConst<ApiType>;
            /**
             * Minimum amount of POLYX that must be bonded for a new bond.
             **/
            minimumBond: BalanceOf & AugmentedConst<ApiType>;
            /**
             * The threshold of improvement that should be provided for a new solution to be accepted.
             **/
            minSolutionScoreBump: Perbill & AugmentedConst<ApiType>;
            /**
             * Number of sessions per era.
             **/
            sessionsPerEra: SessionIndex & AugmentedConst<ApiType>;
            /**
             * Number of eras that slashes are deferred by, after computation.
             *
             * This should be less than the bonding duration.
             * Set to 0 if slashes should be applied immediately, without opportunity for
             * intervention.
             **/
            slashDeferDuration: EraIndex & AugmentedConst<ApiType>;
        };
        statistics: {
            maxTransferManagersPerAsset: u32 & AugmentedConst<ApiType>;
        };
        system: {
            /**
             * Maximum number of block number to block hash mappings to keep (oldest pruned first).
             **/
            blockHashCount: BlockNumber & AugmentedConst<ApiType>;
            /**
             * The maximum length of a block (in bytes).
             **/
            blockLength: BlockLength & AugmentedConst<ApiType>;
            /**
             * Block & extrinsics weights: base values and limits.
             **/
            blockWeights: BlockWeights & AugmentedConst<ApiType>;
            /**
             * The weight of runtime database operations the runtime can invoke.
             **/
            dbWeight: RuntimeDbWeight & AugmentedConst<ApiType>;
            /**
             * The designated SS85 prefix of this chain.
             *
             * This replaces the "ss58Format" property declared in the chain spec. Reason is
             * that the runtime should know about the prefix in order to make use of it as
             * an identifier of the chain.
             **/
            ss58Prefix: u8 & AugmentedConst<ApiType>;
            /**
             * Get the chain's current version.
             **/
            version: RuntimeVersion & AugmentedConst<ApiType>;
        };
        timestamp: {
            /**
             * The minimum period between blocks. Beware that this is different to the *expected* period
             * that the block production apparatus provides. Your chosen consensus system will generally
             * work with this to determine a sensible block time. e.g. For Aura, it will be double this
             * period on default settings.
             **/
            minimumPeriod: Moment & AugmentedConst<ApiType>;
        };
        transactionPayment: {
            /**
             * The fee to be paid for making a transaction; the per-byte portion.
             **/
            transactionByteFee: BalanceOf & AugmentedConst<ApiType>;
            /**
             * The polynomial that is applied in order to derive fee from weight.
             **/
            weightToFee: Vec<WeightToFeeCoefficient> & AugmentedConst<ApiType>;
        };
    }
    interface QueryableConsts<ApiType extends ApiTypes> extends AugmentedConsts<ApiType> {
    }
}
//# sourceMappingURL=augment-api-consts.d.ts.map