import BigNumber from 'bignumber.js';
import { TransactionArgumentType } from "../types";
/**
 * Maximum amount of decimals for on-chain values
 */
export declare const MAX_DECIMALS = 6;
export declare const MAX_TICKER_LENGTH = 12;
export declare const MAX_MODULE_LENGTH = 32;
export declare const MAX_MEMO_LENGTH = 32;
/**
 * Biggest possible number for on-chain balances
 */
export declare const MAX_BALANCE: BigNumber;
/**
 * Account ID used for certain calls that require it when the SDK is instanced without one
 */
export declare const DUMMY_ACCOUNT_ID = "5GrwvaEF5zXb26Fz9rcQpDWS57CtERHpNehXCPcNoHGKutQY";
/**
 * Whether or not to ignore the checksum when encoding/decoding polkadot addresses
 */
export declare const IGNORE_CHECKSUM = true;
/**
 * Default SS58 format for encoding addresses (used when the chain doesn't specify one)
 */
export declare const DEFAULT_SS58_FORMAT = 42;
export declare const MAX_CONCURRENT_REQUESTS = 200;
export declare const TREASURY_MODULE_ADDRESS = "modlpm/trsry";
export declare const DEFAULT_GQL_PAGE_SIZE = 25;
/**
 * Limit to the page size used when fetching large amounts of data from the chain (same goes for `.multi` calls)
 */
export declare const MAX_PAGE_SIZE: BigNumber;
/**
 * Prefix for the data that must be signed in Ethereum by a classic Ticker owner in order
 *   to claim their Ticker
 */
export declare const CLASSIC_CLAIM_SIGNATURE_PREFIX = "classic_claim";
/**
 * "Systematic DID" that owns all classic Tickers until they are claimed by their real owners
 */
export declare const CLASSIC_TICKER_OWNER_DID = "0x73797374656d3a706f6c796d6174685f636c61737369635f6d69670000000000";
/**
 * Maps chain types to more human-readable `TransactionArgumentType`s
 */
export declare const ROOT_TYPES: Record<string, TransactionArgumentType.Did | TransactionArgumentType.Address | TransactionArgumentType.Text | TransactionArgumentType.Boolean | TransactionArgumentType.Number | TransactionArgumentType.Balance | TransactionArgumentType.Date>;
/**
 * The Polymesh version range that is compatible with this version of the SDK
 */
export declare const SUPPORTED_VERSION_RANGE = "4.1.x";
export declare const SYSTEM_VERSION_RPC_CALL: {
    jsonrpc: string;
    method: string;
    params: never[];
};
/**
 * Maximum amount of legs allowed in a single instruction
 */
export declare const MAX_LEGS_LENGTH = 10;
/**
 * Default CDD ID associated with an Identity on chain. Used for Identities onboarded without PUIS
 */
export declare const DEFAULT_CDD_ID = "0x0000000000000000000000000000000000000000000000000000000000000000";
//# sourceMappingURL=constants.d.ts.map